Overview — thelper 0.3.8 documentation

### Navigation

- ☰
- thelper-0.3.8 »

Fork me on GitHub

# Overview

dependencies |
ci-status |
releases |
packages |

This package provides a training framework and CLI for PyTorch-based machine learning projects. This is free software distributed under the Apache Software License version 2.0 built by researchers and developers from the Centre de Recherche Informatique de Montréal / Computer Research Institute of Montreal (CRIM).

To get a general idea of what this framework can be used for, visit the FAQ page. For installation instructions, refer to the installation guide. For usage instructions, refer to the user guide. The auto-generated documentation is available via readthedocs.io.

## Notes

Development is still on-going — the API and internal classes may change in the future.

The project’s structure was originally generated by cookiecutter via ionelmc’s template.

### Navigation

- index
- modules |
- next |
- previous |